############################ 6.Tutorial ######################################

#MANOVA ASSUMPTIONS
# 1) Observations are randomly and independently sampled from the population
# 2) Dependent variables are multivariate normally distributed within each group of the independent variables (which are categorical)
# 3) The population covariance matrices of each group are equal


#load the data
ocdData <- read.delim("OCD.dat", header = TRUE)
#reorder the levels of factor and rename it
ocdData$Group <- factor(ocdData$Group, levels = c("CBT", "BT", "No Treatment Control"),
                        labels = c("CBT", "BT", "NT"))

#CBT - cognitive-behaviour therapy
#BT - behaviour therapy


#data vizualization
plot(ocdData$Actions, ocdData$Thoughts, col = ocdData$Group,
     main = "OCD data", xlab = "Actions", ylab = "Thoughts")
legend("topleft", levels(ocdData$Group), col = c(1,2,3),
       pch=20, cex = 0.8)

#looking at the relationship between thoughts and actions for the different conditions
#scatterplot
xlim <- range(ocdData$Actions)
ylim <- range(ocdData$Thoughts)
ocdData_Grouped <- split(ocdData, f = ocdData$Group)
par(mfrow=c(1,3))
for(f in names(ocdData_Grouped)){
  tmpData <- ocdData_Grouped[[f]]
  fit1 <- lm(tmpData$Thoughts ~ tmpData$Actions)
  plot(tmpData$Actions, tmpData$Thoughts, xlim = xlim, ylim = ylim,
       main = f, xlab = "Actions", ylab = "Thoughts")
  abline(fit1,lwd=1,col="red")
}

#barplot .....

#boxplot
ylim <- range(ocdData[,-1])
par(mfrow = c(1,3))
boxplot(ocdData_Grouped$CBT[,-1], main = "CBT", ylim = ylim, range = 1.5)
boxplot(ocdData_Grouped$BT[,-1], main = "BT", ylim = ylim, range = 1.5)
boxplot(ocdData_Grouped$NT[,-1], main = "NT", ylim = ylim, range = 1.5)

library(pastecs)
by(ocdData$Actions, ocdData$Group, stat.desc, basic = FALSE)
by(ocdData$Thoughts, ocdData$Group, stat.desc, basic = FALSE)

#variance-covariance matrices
by(ocdData[,-1], ocdData$Group, cov)

#homogeneity of covariance matrices
source("boxTest.R")
BoxMTest(ocdData[,-1],cl = ocdData$Group)
# or BoxM function from library(biotools)

#multivariate normality
#mvnormtest package - fce mshapiro.test()
library(mvnormtest)
mshapiro.test(t(ocdData_Grouped$CBT[,-1]))
mshapiro.test(t(ocdData_Grouped$BT[,-1]))
mshapiro.test(t(ocdData_Grouped$NT[,-1]))

library(MVN)
#outlierCBT <- mvOutlier(ocdData_Grouped$CBT[,-1], qqplot = TRUE, method = "adj.quan")
#outlierBT <- mvOutlier(ocdData_Grouped$BT[,-1], qqplot = TRUE, method = "adj.quan")
outlierNT <- mvOutlier(ocdData_Grouped$NT[,-1], qqplot = TRUE, method = "adj.quan")

#ocdNoOutlier <-rbind(cbind(outlierCBT$newData, Group = "CBT"))
#ocdNoOutlier <-rbind(ocdNoOutlier, cbind(outlierBT$newData, Group = "BT"))
ocdNoOutlier <-rbind(cbind(ocdData_Grouped$CBT[,-1], Group = "CBT"))
ocdNoOutlier <-rbind(ocdNoOutlier, cbind(ocdData_Grouped$BT[,-1], Group = "BT"))
ocdNoOutlier <-rbind(ocdNoOutlier, cbind(outlierNT$newData, Group = "NT"))


#control
mvOutlier(outlierCBT$newData, qqplot = TRUE, method = "adj.quan")
mvOutlier(outlierBT$newData, qqplot = TRUE, method = "adj.quan")
mvOutlier(outlierNT$newData, qqplot = TRUE, method = "adj.quan")
mshapiro.test(t(outlierCBT$newData))
mshapiro.test(t(outlierBT$newData))
mshapiro.test(t(outlierNT$newData))

#manova
outcome <- cbind(ocdNoOutlier$Actions, ocdNoOutlier$Thoughts)
ocdModel <- manova(outcome ~ Group, data = ocdNoOutlier)
summary(ocdModel, intercept = TRUE)
summary(ocdModel, intercept = TRUE, test = "Wilks")
summary(ocdModel, intercept = TRUE, test = "Hotelling")
summary(ocdModel, intercept = TRUE, test= "Roy")

#follow-up analysis: univariate test statistics
summary.aov(ocdModel)
#or
anovaActions <- anova(lm(ocdNoOutlier$Actions ~ ocdNoOutlier$Group))
anovaThoughts <- anova(lm(ocdNoOutlier$Thoughts ~ ocdNoOutlier$Group))

#### WITH OUTLIERS

#manova
outcome <- cbind(ocdData$Actions, ocdData$Thoughts)
ocdModel <- manova(outcome ~ Group, data = ocdData)
summary(ocdModel, intercept = TRUE, test = "Pillai")
summary(ocdModel, intercept = TRUE, test = "Wilks")
summary(ocdModel, intercept = TRUE, test = "Hotelling")
summary(ocdModel, intercept = TRUE, test= "Roy")

#follow-up analysis: univariate test statistics
summary.aov(ocdModel)
#or
anovaActions <- anova(lm(ocdData$Actions ~ ocdData$Group))
anovaThoughts <- anova(lm(ocdData$Thoughts ~ ocdData$Group))

